@@ -13,7 +13,7 @@ import (
 type Parser struct{}
 
 // Unmarshal unmarshals CycloneDX files.
-func (*Parser) Unmarshal(p []byte, v interface{}) error {
+func (*Parser) Unmarshal(p []byte, v any) error {
 	bomFileFormat := cyclonedx.BOMFileFormatJSON
 	if !json.Valid(p) {
 		bomFileFormat = cyclonedx.BOMFileFormatXML
@@ -29,18 +29,18 @@ func (*Parser) Unmarshal(p []byte, v interface{}) error {
 	if bomFileFormat == cyclonedx.BOMFileFormatXML {
 		var data cyclonedx.BOM
 		if err := xml.Unmarshal(p, &data); err != nil {
-			return fmt.Errorf("unmarshalling XML error: %v", err)
+			return fmt.Errorf("unmarshaling XML error: %v", err)
 		}
 		if d, err := json.Marshal(data); err == nil {
 			temp = d
 		} else {
-			return fmt.Errorf("marshalling JSON error: %v", err)
+			return fmt.Errorf("marshaling JSON error: %v", err)
 		}
 	}
 
 	err := json.Unmarshal(temp, v)
 	if err != nil {
-		return fmt.Errorf("unmarshalling JSON error: %v", err)
+		return fmt.Errorf("unmarshaling JSON error: %v", err)
 	}
 
 	return nil
