@@ -17,7 +17,7 @@ func TestHoconUnmarshal(t *testing.T) {
 	}
 }`
 
-	var input interface{}
+	var input any
 	if err := parser.Unmarshal([]byte(sample), &input); err != nil {
 		t.Fatalf("parser should not have thrown an error: %v", err)
 	}
@@ -26,9 +26,9 @@ func TestHoconUnmarshal(t *testing.T) {
 		t.Error("there should be information parsed but its nil")
 	}
 
-	inputMap := input.(map[string]interface{})
+	inputMap := input.(map[string]any)
 	item := inputMap["play"]
-	if len(item.(map[string]interface{})) == 0 {
+	if len(item.(map[string]any)) == 0 {
 		t.Error("there should be at least one item defined in the parsed file, but none found")
 	}
 }
