@@ -27,7 +27,7 @@ func TestJSONParser(t *testing.T) {
   }
 }`
 
-	var input interface{}
+	var input any
 	if err := parser.Unmarshal([]byte(sample), &input); err != nil {
 		t.Fatalf("parser should not have thrown an error: %v", err)
 	}
@@ -36,7 +36,7 @@ func TestJSONParser(t *testing.T) {
 		t.Fatalf("there should be information parsed but its nil")
 	}
 
-	inputMap := input.(map[string]interface{})
+	inputMap := input.(map[string]any)
 	if len(inputMap) == 0 {
 		t.Error("there should be at least one item defined in the parsed file, but none found")
 	}
